Sign in Join

Live chat for Free Pascal, Lazarus, Delphi and every Pascal programmer.

Mailing lists / fpc-devel / 2006-06

Updates to FCL/XML stuff

3 messages · 2 people · –

Reply by email Subscribe to this list Your subscription

Read-only archive. Use j and k to move between messages.

Sergei Gorelkin

Hello,

Attached are further improvements to XML handling classes. I am sending the whole files instead of patches, because patches are larger than the files :)

During the time passed, I have got my hands on a test suite from w3.org and on a profiler. So the code now is much more "mature" than in the previous changes.

The current status is:

- xmlwrite.pp: Implemented built-in buffering with simultaneous UTF8 encoding, which made it faster about 3 times.
- dom.pp: Implemented a number of missing methods; wrote a skeleton for namespace support (not working yet); implemented timestamping for TDOMNodeList (so it is rebuilt only when underlying nodes are changed). The complete list of changes is in 'FIX:' and 'DONE:' comments in dom.pp itself.
- xmlread.pp: Numerous fixes in order to improve performance and comply with the testsuite.

Best regards, Sergei

Reply by email

Michael Van Canneyt
to Sergei Gorelkin
Sergei Gorelkin wrote 20 lines
Hello, Attached are further improvements to XML handling classes. I am sending the whole files instead of patches, because patches are larger than the files :) During the time passed, I have got my hands on a test suite from w3.org and on a profiler. So the code now is much more "mature" than in the previous changes. The current status is: - xmlwrite.pp: Implemented built-in buffering with simultaneous UTF8 encoding, which made it faster about 3 times. - dom.pp: Implemented a number of missing methods; wrote a skeleton for namespace support (not working yet); implemented timestamping for TDOMNodeList (so it is rebuilt only when underlying nodes are changed). The complete list of changes is in 'FIX:' and 'DONE:' comments in dom.pp itself. - xmlread.pp: Numerous fixes in order to improve performance and comply with the testsuite.

I will apply the patch tonight.

Michael.

Reply by email

Michael Van Canneyt
to Sergei Gorelkin: Attached are further improvements to XML handling classes. I am sending the whole files…
Sergei Gorelkin wrote 20 lines
Hello, Attached are further improvements to XML handling classes. I am sending the whole files instead of patches, because patches are larger than the files :) During the time passed, I have got my hands on a test suite from w3.org and on a profiler. So the code now is much more "mature" than in the previous changes. The current status is: - xmlwrite.pp: Implemented built-in buffering with simultaneous UTF8 encoding, which made it faster about 3 times. - dom.pp: Implemented a number of missing methods; wrote a skeleton for namespace support (not working yet); implemented timestamping for TDOMNodeList (so it is rebuilt only when underlying nodes are changed). The complete list of changes is in 'FIX:' and 'DONE:' comments in dom.pp itself. - xmlread.pp: Numerous fixes in order to improve performance and comply with the testsuite.

I already committed it. (revision 3973)

2 questions:
- Did you test this with 2.0.3 ? If so, I can merge it to fixes.
- I would be interested in the testsuite, so we can commit that to SVN too. The more test programs we have, the better it is.

Michael.

Reply by email